**Example 1: 创建逃逸事件导出异步任务**



Input: 

```
tccli tcss CreateEscapeEventsExportJob --cli-unfold-argument  \
    --ExportField xxx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx",
        "JobId": "xx"
    }
}
```

